# QuickStart Application

The Quickstart application was developed by EPAM and donated to the OSDU Forum.

This application is designed for demonstration purposes only.

The providing functionality is:
- Searching for wells by name
- Searching for wells on map 
- Viewing wells on map
- Viewing the wellbores list of a well
- Plotting wellbore 3D trajectories
- Plotting a cross-section for a set of wells

The application comprises:

- [Python backend](/python-backend/README.md)
- [React frontend](/react-frontend/README.md)

# Running Quickstart

You can run Quickstart in either way:

- run the [backend](/python-backend/README.md) and [frontend](/react-frontend/README.md) independently;
- (preferably) use Docker.

## Configuring

Go to the `python-backend` folder, rename the default environment file to `config-backend.env` and fill the values. The environment file configures the backend providing the information required to connect to the OSDU Data Platform.

## Prerequisites to run on Docker

1. Install [Docker Desktop](https://www.docker.com/products/docker-desktop), if you are using Windows or Mac. On Linux, install [Docker Engine](https://docs.docker.com/engine/install/). If you are using WSL on Windows, you should also install `docker-compose`.

2. On Windows, make sure the host daemon is exposed.

<details>
  <summary>Click to see the screenshot</summary>
  
!["Docker Host Exposed"](compose/Docker_Host_Exposed.png)
  
</details>

## Orchestration

4. Change to the `compose` folder. There is `docker-compose.yml` file which serves as instructions for the docker-compose service. This file already contains all the necessary instruction. You can change ports and rename config file paths if needed.

5. Check `.env` file and verify that variables are correct for your project. This file is recognized by `docker-compose` and the environment variables are automatically applied from there when the tool reads the configuration from `docker-compose.yml`.

6. Verify the docker-compose configuration

~~~bash
$ docker-compose config

services:
  client:
    build:
      context: /home/user/quickstart/react-frontend/essentials
    depends_on:
    - server
    environment:
      AUTH_SERVER_PORT: '8080'
      FETCH_SERVER_PORT: '8080'
      FIND_SERVER_PORT: '8080'
    ports:
    - 3000:3000/tcp
  server:
    build:
      context: /home/user/quickstart/python-backend/essentials
    environment:
      OSDU_API_DELIVERY_URL: <delivery-url>
      OSDU_API_SEARCH_URL: <search-url>
      OSDU_AUTH_CLIENT_ID: ****
      OSDU_AUTH_CLIENT_SECRET: ****
      OSDU_AUTH_DISCOVERY_URL: <auth-discovery-url>
      OSDU_AUTH_REDIRECT_URL: http://localhost:8080/auth/callback
      OSDU_AUTH_SCOPES: openid,email
      OSDU_TARGET_PLATFORM: azure | gcp | aws | ibm
    ports:
    - 8080:8080/tcp
version: '3.0'
~~~

~~~bash
services:
  client:
    build:
      context: /home/user/quickstart/react-frontend
    depends_on:
      server:
        condition: service_started
    environment:
      BACKEND_HOST: server
      BACKEND_PORT: '8080'
    ports:
    - published: 3000
      target: 3000
  server:
    build:
      context: /home/user/quickstart/python-backend
    environment:
      OSDU_API_FILE_URL: <file_service_url>
      OSDU_API_SEARCH_URL: <search_service_url>
      OSDU_API_STORAGE_URL: <storage_service_url>
      OSDU_AUTH_CLIENT_ID: ****
      OSDU_AUTH_CLIENT_SECRET: ****
      OSDU_AUTH_DISCOVERY_URL: <auth_discovery_url>
      OSDU_AUTH_LOGOUT_URL: http://localhost:8080/end_session/callback
      OSDU_AUTH_REDIRECT_URL: http://localhost:8080/auth/callback
      OSDU_AUTH_SCOPES: openid profile offline_access
      OSDU_DATA_PARTITION: <partition>
      OSDU_TARGET_PLATFORM: <platform>
    ports:
    - published: 8080
      target: 8080
version: '3'
~~~

7. Start the containers and navigate to http://localhost:3000 to check if it is working properly, so that the frontend is communicating to the backend as expected.

~~~bash
$ docker-compose up

Recreating compose_server_1 ... done
Recreating compose_client_1 ... done
Attaching to compose_server_1, compose_client_1
server_1  | [2020-02-21 23:25:54 +0000] [6] [INFO] Starting gunicorn 19.9.0
server_1  | [2020-02-21 23:25:54 +0000] [6] [INFO] Listening at: http://0.0.0.0:8080 (6)
server_1  | [2020-02-21 23:25:54 +0000] [6] [INFO] Using worker: sync
server_1  | [2020-02-21 23:25:54 +0000] [9] [INFO] Booting worker with pid: 9
client_1  |
client_1  | > osdu@0.1.0 serve /app
client_1  | > node server.js
client_1  | 
client_1  | [HPM] Proxy created: /api  -> http://server:8080
client_1  | [HPM] Proxy rewrite rule created: "^/api" ~> "/"
client_1  | [HPM] Proxy created: /login  -> http://server:8080
client_1  | [HPM] Proxy created: /logout  -> http://server:8080
client_1  | App is listening on port 3000
~~~
