# Python-backend
This is the backend of the Quickstart application.

## Configure
1. Get the Client ID, Client Secret, API endpoints URLs from your admin.
2. Go to the `python-backend` folder, rename default environment file to config-backend.env and fill out the values:
```
# OSDU instances are not 100% equal across different cloud providers
# Set the correct value here as portions of the code are cloud specific
OSDU_TARGET_PLATFORM=aws|azure|gcp|ibm

# Auth settings
# Usually provided by your cloud administrator
OSDU_AUTH_CLIENT_ID=<your-client-id>
OSDU_AUTH_CLIENT_SECRET=<your-client-secret>
OSDU_AUTH_DISCOVERY_URL=<auth-server-url>
# Redirect URL Example: http://localhost:8080/auth/callback 
OSDU_AUTH_REDIRECT_URL=<your-redirect-url>
# Redirect URL for logout flow, example: http://localhost:8080/end_session/callback
OSDU_AUTH_LOGOUT_URL=<your-logout-url>
# Scopes usually depend on the specific cloud provider:
# Example for AWS: openid,email
OSDU_AUTH_SCOPES=<requested-scopes>

# Data partition id is the required header to designate the data partition in a multi-tenant system
OSDU_DATA_PARTITION=<data-partition>

# API settings
# Search API usually ends with /query
OSDU_API_SEARCH_URL=<search-api-url>
# File API usually ends with /files
OSDU_API_FILE_URL=<file-api-url>
```

## How to run locally 

You can run the backend locally on Mac, Linux, or Windows. On Windows, you will need [WSL](https://docs.microsoft.com/en-us/windows/wsl/install-win10).

1. Download and install Python.
2. Create and activate virtual environment:
```
$ python3 -m venv --prompt training .venv/training
$ source .venv/training/bin/activate
```
3. Install required packages:
```
$ pip install -r requirements.txt
```
4. If your version of Python3 is 3.6 or less, install one more package:
```
$ pip install dataclasses
```
5. Export environment variables:

```
$ export $(grep -v '^#' config-backend.env | xargs -d '\n')
```

6. Run the server in python-backend folder:
```
$ gunicorn src.entry_api:api -b 0.0.0.0:8080
```
7. Go to http://localhost:8080/login.
This will initiate the sign-in process and you will need to sign-in.
If successfull, it will dump the tokens back to your browser.

## How to run in Docker container

1. Edit `docker-compose.yml` to include configuration to your environment:
```
version : '3'
services:
  backend:
    env_file:
      - config-backend.env
    build: .
    ports:
      - "8080:8080"
    command: gunicorn src.entry_api:api -b 0.0.0.0:8080 --reload
```
2. Build the image and run the container:
```
$ docker-compose up --build
```
3. Go to http://localhost:8080/login

## Development configuration

1. Activate virtual environment:
```
$ source .venv/training/bin/activate
```

2. Install dev packages:
```
$ pip install -r dev-requirements.txt
```

## How to run tests locally

1. Activate virtual environment:
```
$ source .venv/training/bin/activate
```
2. Run unittests in python-backend folder:
```
$ python -m unittest discover -s tests/ -p 'test_*.py'
```
