"""Client module to configure Auth and OpenId Connect settings."""
from oic.oic import Client
from oic.oic.message import RegistrationResponse
from oic.utils.authn.client import CLIENT_AUTHN_METHOD

from src.settings import (OSDU_AUTH_CLIENT_ID, OSDU_AUTH_CLIENT_SECRET,
                          OSDU_AUTH_DISCOVERY_URL, OSDU_AUTH_LOGOUT_URL,
                          OSDU_AUTH_REDIRECT_URL, OSDU_AUTH_SCOPES)

# scopes depend on the cloud provider
# * [openid] - required for OpenID Connect flow
# * [email] - allows reading user email
# * [offline_access] - required to get
#       refresh_token (Microsoft ONLY)
scopes = []
for item in OSDU_AUTH_SCOPES.split(","):
    scopes.append(item)


# get ClientID and ClientSecret and Auth Server URL
# from your cloud administrator or cloud provider
# OSDU_AUTH_DISCOVERY_URL is your discovery URL
oidc_client = Client(client_authn_method=CLIENT_AUTHN_METHOD, verify_ssl=False)
oidc_client.provider_config(issuer=OSDU_AUTH_DISCOVERY_URL)

# Store the registration credentials
registration_info = RegistrationResponse(
    client_id=OSDU_AUTH_CLIENT_ID,
    client_secret=OSDU_AUTH_CLIENT_SECRET,
)
oidc_client.store_registration_info(registration_info)

oidc_client.redirect_uris = [
    OSDU_AUTH_REDIRECT_URL,
    OSDU_AUTH_LOGOUT_URL,
]
