"""Session management module."""
from dataclasses import dataclass
from typing import Dict, Optional

from src.settings import OSDU_DATA_PARTITION


@dataclass
class Session:
    """Session structure to keep the app state and auth tokens."""

    session_id: str
    state: str
    id_token: str = ""
    access_token: str = ""
    refresh_token: str = ""

    def __repr__(self) -> str:
        """Define custom session representation method."""
        return f"Session(session_id={self.session_id}, state={self.state})"

    def create_authorization_headers(self) -> Optional[Dict[str, str]]:
        """Create headers for any OSDU API requests (helper method).

        This method extracts authorization tokens for create authorization headers
        for each platform and return these headers.
        """
        # access_token is used as "Authorization" header
        headers = {
            "data-partition-id": OSDU_DATA_PARTITION,
            "Authorization": f"Bearer {self.access_token}",
        }
        return headers
