## File API Documentation

1. Fetch trajectories information (MeasuredDepth, Azimuth, Inclination, x, y) by wellbore_id
```
METHOD: GET
URI: /fetch/trajectory_by_wellbore_id
```
For example:
```
URL: http://localhost:8080/fetch/trajectory_by_wellbore_id?wellbore_id=opendes:master-data--Wellbore:3693
```
This should return an object (consist three keys: wellbore_id and data (object))
```
{
    "wellbore_id": "opendes:master-data--Wellbore:3693",
    "data": {
        "measured_depths": [14.97, ...],
        "azimuths": [117.57, ...],
        "inclinations": [0.06, ...],
        "surface_x": [254732.0, ...],
        "surface_y": [599764.0, ...]
    }
}
```


## Diagrams

[Mermaid Manual](https://mermaid-js.github.io/mermaid/#/sequenceDiagram)


### Sequence diagram of fetch/trajectory_by_wellbore_id


```
sequenceDiagram
    participant Frontend
    participant Backend router
    participant Middleware
    participant .on_get
    participant .get_file_ids_from_search
    participant .get_file_ids_from_search_results
    participant .extract_trajectory
    participant Blob storage
    participant OSDU Search API
    participant OSDU File API

    Note over .on_get, .extract_trajectory: class FetchTrajectoryByWellboreIDResource

    Frontend->>+Backend router: GET: /fetch/trajectory_by_wellbore_id
    Backend router->>+Middleware: checks auth session from cookie
    Middleware->>+.on_get: set request data (wellbore_id)
    .on_get->>+.get_file_ids_from_search: wellbore_id
    .get_file_ids_from_search->>+OSDU Search API: POST: /search/v2/query (wellbore_id in search query)
    OSDU Search API-->>-.get_file_ids_from_search: returns response json with trajectory object
    .get_file_ids_from_search->>+.get_file_ids_from_search_results: response json
    .get_file_ids_from_search_results-->>-.get_file_ids_from_search: returns list with files' ids
    .get_file_ids_from_search-->-.on_get: returns list with files' ids
    .on_get->>+OSDU File API: GET: {file_id}/downloadURL (fle id from search responce)
    OSDU File API-->>-.on_get: returns  SignedUrl property from response
    .on_get->>+.extract_trajectory: gets trajectory by resource credentials
    .extract_trajectory->>+Blob storage: download file
    Blob storage-->>-.extract_trajectory: returns file
    .extract_trajectory-->>-.on_get: returns extracted trajectory info <br> (depths, azimuths, inclinations)
    .on_get-->>-Frontend: returns response with extracted trajectory information
```
