## Search API Documentation

1. Find all wells by (part or proposal) well name:
```
METHOD: GET
URI: /find/wells_by_name
```
For example:
```
URL: http://localhost:8080/find/wells_by_name?well_name=BIR
```
This should return a list of well objects with keys: well_id, facility_id
```
{
    "wells": [
        {
            "well_id": "opendes:master-data--Well:3687",
            "facility_id": "BIR-13",
            "location": {
                "coordinates": [
                    6.88516879,
                    53.37353031
                ],
                "type": "point"
            }
        },
        {
            ...
        }
    ]
}
```

2. Find wellbores by well_id:
```
METHOD: GET
URI: /find/wellbores_by_well_id
```
For example:
```
URL: http://localhost:8080/find/wellbores_by_well_id?well_id=opendes:master-data--Well:3687:
```
This should return a list of wellbore objects with keys: well_id and wellbore_name
```
{
    "wellbores": [
        {
            "wellbore_id": "opendes:master-data--Wellbore:3687", 
            "wellbore_name": "BIR-13"
        },
        {
            ...
        }
    ]
}
```

3. Find all wells in polygon
```
METHOD: POST
URI: /find/wells_in_polygon
```
For example:
```
METHOD: POST
URL: http://localhost:8080/find/wells_in_polygon
BODY:
{
    "type": "Polygon",
    "coordinates": [
            [
                [3.01025390625, 52.284962354465726],
                [3.1091308593749996, 52.13685974852633],
                [3.438720703125, 52.217704193421454],
                [3.01025390625, 52.284962354465726]
            ]
    ]
}
```
This should return a list of well objects
```
[
    {
        "well_id": "opendes:master-data--Well:7443",
        "facility_id": "P13-02",
        "location": {
            "coordinates": [
                3.108628,
                52.266782
            ],
            "type": "point"
        }
    },
    {
        ...
    }
]
```


## Diagrams

[Mermaid Manual](https://mermaid-js.github.io/mermaid/#/sequenceDiagram)


### Sequence diagram of find/wells_by_name


```mermaid
sequenceDiagram
    participant Frontend
    participant Backend router
    participant Middleware
    participant .on_get
    participant .get_wells
    participant OSDU Search API

    Note over .on_get, .get_wells: class FindWellsByNameResource
  
    Frontend->>+Backend router: GET: /find/wells_by_name
    Backend router->>+Middleware: checks auth session from cookie
    Middleware->>+.on_get: set request data (well_name)
    .on_get->>+OSDU Search API: POST: /search/v2/query (well_name in search query)
    OSDU Search API-->>-.on_get: returns response json with found wells
    .on_get->>+.get_wells: response json
    .get_wells-->>-.on_get: necessary info of wells <br><br> (well_id, facility_id)
    .on_get-->>-Frontend: returns response with extracted wells information
```


### Sequence diagram of find/wellbores_by_well_id


```mermaid
sequenceDiagram
    participant Frontend
    participant Backend router
    participant Middleware
    participant .on_get
    participant .get_wellbores_from_search_response
    participant .extract_wellbore_name
    participant OSDU Search API

    Note over .on_get, .get_wellbores_from_search_response: class FindWellboresByWellIDResource

    Frontend->>+Backend router: GET: /find/wellbores_by_well_id
    Backend router->>+Middleware: checks auth session from cookie
    Middleware->>+.on_get: set request data (well_id)
    .on_get->>+OSDU Search API: POST: /search/v2/query (well_id in search query)
    OSDU Search API-->>-.on_get: returns response json with found wellbores
    .on_get->>+.get_wellbores_from_search_response: response json
    .get_wellbores_from_search_response->>+.extract_wellbore_name: extracts wellbore's name from record
    .extract_wellbore_name-->>-.get_wellbores_from_search_response: returns wellbore's name
    .get_wellbores_from_search_response-->>-.on_get: necessary info of wellbores <br><br> (wellbore_id, wellbore_name)
    .on_get-->>-Frontend: returns response with extracted wellbores information
```


### Sequence diagram of find/wells_in_polygon


```mermaid
sequenceDiagram
    participant Frontend
    participant Backend router
    participant Middleware
    participant .on_post
    participant .transform_polygon
    participant .get_wells
    participant OSDU Search API

    Note over .on_post, .get_wells: class FindWellsInPolygonResource

    Frontend->>+Backend router: POST: /find/wells_in_polygon
    Backend router->>+Middleware: checks auth session from cookie
    Middleware->>+.on_post: set request data (polygon)
    .on_post->>+.transform_polygon: gets GeoJSON polygon
    .transform_polygon-->>-.on_post: returns OpenDES polygon
    .on_post->>+OSDU Search API: POST: /search/v2/query (polygon in search query)
    OSDU Search API-->>-.on_post: returns response json with found wells
    .on_post->>+.get_wells: response json
    .get_wells-->>-.on_post: necessary info of wells <br> (well_id, facility_id, location)
    .on_post-->>-Frontend: returns response with extracted wells information
```
