""" -----------------------------------------------------------------
 unittest module for find_wellbores_by_well_id resource
 ----------------------------------------------------------------- """

from unittest.mock import patch

from falcon import API, testing, Request

from src.find import FindWellboresByWellIDResource

MOCK_OSDU_DATA_PARTITION = "opendes"
MOCK_WELL_ID = f"{MOCK_OSDU_DATA_PARTITION}:master-data--Well:3687:"
MOCK_RESOURCE_ID = f"{MOCK_OSDU_DATA_PARTITION}:master-data--Wellbore:3687:"
MOCK_WELLBORE_NAME = "BIR-13"

REQUEST_PARAMS_MOCK = {"well_id": MOCK_WELL_ID}

OSDU_API_SEARCH_RESPONSE_MOCK = {
    "results": [
        {
            "id": MOCK_RESOURCE_ID,
            "data": {
                "NameAliases": [
                    {
                        "AliasNameTypeID": f"{MOCK_OSDU_DATA_PARTITION}:reference-data--AliasNameType:Borehole%20Code:",
                        "AliasName": MOCK_WELLBORE_NAME}
                ]
            }
        }
    ]
}


RESPONSE_JSON = {
    "wellbores": [{
        "wellbore_id": MOCK_RESOURCE_ID,
        "wellbore_name": MOCK_WELLBORE_NAME,
    }]
}

req_init = Request.__init__


def mock_falcon_request(req, *args, **kwargs):
    """
    Input params: req and args with env parameters and kwargs with request options.
    Function changes env parameters in falcon request for add mock well name
    """
    env = testing.create_environ(
        path=args[0]["PATH_INFO"],
        query_string="well_id={}".format(MOCK_WELL_ID))
    req_init(req, env, **kwargs)


class BaseTestAPICase(testing.TestCase):
    """Base test API case which set up API and adds route"""

    def setUp(self):
        super(BaseTestAPICase, self).setUp()

        app = API()
        app.add_route("/find/wellbores_by_well_id",
                      FindWellboresByWellIDResource())

        self.app = app


class TestFindWellboresByWellIDResource(BaseTestAPICase):
    """Checks test case situations in find_wellbores_by_well_id request handler."""

    @patch("src.find.find_wellbores_by_well_id.call_search_api")
    def test_find_wellbores_by_well_id_success(self, call_search_api_mock):
        """
        This test case checks success situation in find_wellbores_by_well_id request handler.
        """
        # mocks call_search_api function result
        call_search_api_mock.return_value = OSDU_API_SEARCH_RESPONSE_MOCK
        # simulates request with mock request parameters and headers

        with patch("falcon.request.Request.__init__", mock_falcon_request):
            response = self.simulate_get("/find/wellbores_by_well_id")

        # checks response parameters
        self.assertEqual(response.status_code, 200)
        self.assertIsInstance(response.json, dict)
        self.assertEqual(response.json, RESPONSE_JSON)
