# Source Code

## folders stucture

### api

- contains request and responce model interfaces
- ultimate fetch call composition

### components

- every react-component but pages
- feature-divided subfolders
  - for such a small project it is easier to give away some neat reusability in favor of feature independence
- shared folder for share
  - for common components such as Loader

### test-data

- mocks for tests
  - api responses
  - reducer states
- feature-divided subfolders

### lib

- data convertion and special objects for specific external library
  - math and config for a 3D trajectory
  - data convertion for a cross-section

### pages

- project's page-devision
- among all the react-components, pages are
  - logical entry points for a user
  - subject to routing and once-per-page effects

### store

redux store, groupped by features

- types.ts
  - action type constants
  - action payload typing
- actions.ts
  - action composition
  - the only place to invoke api methods from the /api folder
- reducer.ts
  - feature's store interface and its initial state
  - actions-to-state reducing
  - the only place to parse api response model

## index files rationale

index.ts files are stored in certain folders to provide cleaner access using import and to introduce some level of encapsulation by a common arrangement.

if some entity should be used out of its folder, it should be declared in corresponding index file

### components + feature -> index

access to components, related to the feature and allowed to be imported from an external

### lib + feature -> index

access to external library interactions related to the feature and allowed to be imported from an external

### store -> index

access to the AppStore

### store + feature -> index

access to the feature's exposed actions and a reducer model

## Testing challenges

### enzyme + redux<react hooks>

it is not possible to use

```
expect(shallow(<Component/>)).toMatchSnapshot()
```

on a Connected component becase of a known error, and in a possible solution

```
expect(shallow(<Provider store={store}><Component/></Provider>).dive()).toMatchSnapshot()
```

a dive does not really occurs, leaving Component unrendered.
@see https://github.com/airbnb/enzyme/issues/2202

As a decision for the project:

- a Connected- component must be derived and all connections to a store must be moved to it
- it then will NOT be tested AT ALL
- only dumb Components will be comprehensively tested by a snapshoting

### elements existence

- do not check single elements presence - verified snapshot is enough
- do check collections of elements - it is attention-demanding to manually count, looking at a snapshot
  - do automatically compare rendered quantity to a corresponding collection's length
