import { handleErrors } from './handle-errors';
import { Polygon } from 'geojson';

type FetchWellsInPolygonRequest = Polygon;

export type FetchWellsInPolygonResponse = FetchWellInPolygonResponse[];

/* eslint-disable @typescript-eslint/camelcase */
interface FetchWellInPolygonResponse {
  well_id: string;
  facility_id: string;
  location: {
    coordinates: [number, number];
    type: string;
  };
}
/* eslint-enable @typescript-eslint/camelcase */

/**
 * Returns a list of wells, located within a given polygon
 * no pagination is implemented, results are limited by the backend (99 atm)
 * Error handler is included
 * @param {Polygon} polygon
 */
export function fetchWellsInPolygon(polygon: Polygon): Promise<FetchWellsInPolygonResponse> {
  const body: FetchWellsInPolygonRequest = polygon;

  return fetch('/api/find/wells_in_polygon', {
    headers: { 'content-type': 'application/json' },
    method: 'POST',
    body: JSON.stringify(body),
  })
    .then(handleErrors)
    .then(response => response.json());
}
