import { handleErrors } from './handle-errors';

export interface FindWellsResponse {
  wells: Well[];
}

/* eslint-disable @typescript-eslint/camelcase */
interface Well {
  well_id: string;
  facility_id: string;
  location: {
    coordinates: [number, number];
    // probably it should be of GeoJsonTypes type and possible to parse using library,
    // but from api we receive 'point', not 'Point' and parsing fails.
    // anyway, we have no need in such a deep integration, a lat-lng pair will sufice
    type: string;
  };
}
/* eslint-enable @typescript-eslint/camelcase */

/**
 * Returns a list of wells, found by a given name
 * no pagination is implemented, results are limited by the backend (99 atm)
 * Error handler is included
 * @param {string} wellName
 */
export function findWellsByName(wellName: string): Promise<FindWellsResponse> {
  return fetch(`/api/find/wells_by_name?well_name=${wellName}`)
    .then(handleErrors)
    .then(response => response.json());
}

export interface FindWellboresResponse {
  wellbores: Wellbore[];
}

interface Wellbore {
  wellbore_id: string;
  wellbore_name: string;
}

/**
 * Returns a collection of wellbores for a given well
 * Error handler is included
 * @param wellId
 */
export function findWellbores(wellId: string): Promise<FindWellboresResponse> {
  return fetch(`/api/find/wellbores_by_well_id?well_id=${wellId}`)
    .then(handleErrors)
    .then(response => response.json());
}
