import { crossSectionReducer } from './reducer';
import {
  crossSectionInitialState,
  crossSectionLoadDataFailState,
  crossSectionLoadDataStartState,
  crossSectionLoadDataSuccessState,
  crossSectionResponse,
} from 'test-data/cross-section';
import {
  LOAD_WELLS_DATA_START,
  LOAD_WELLS_DATA_FAIL,
  LOAD_WELLS_DATA_SUCCESS,
  CrossSectionActionTypes,
} from './types';

describe('Cross-section reducer', () => {
  it('should return default state', () => {
    expect(crossSectionReducer(undefined, {} as CrossSectionActionTypes)).toEqual(
      crossSectionInitialState
    );
  });

  it('should handle LOAD_WELLS_DATA_START', () => {
    expect(
      crossSectionReducer(crossSectionInitialState, {
        type: LOAD_WELLS_DATA_START,
        payload: ['opendes:master-data--Well:1111', 'opendes:master-data--Well:2222'],
      })
    ).toEqual(crossSectionLoadDataStartState);
  });

  it('should handle LOAD_WELLS_DATA_FAIL', () => {
    expect(
      crossSectionReducer(crossSectionLoadDataStartState, {
        type: LOAD_WELLS_DATA_FAIL,
        payload: Error('Forbidden'),
      })
    ).toEqual(crossSectionLoadDataFailState);
  });

  it('should handle LOAD_WELLS_DATA_SUCCESS', () => {
    expect(
      crossSectionReducer(crossSectionLoadDataStartState, {
        type: LOAD_WELLS_DATA_SUCCESS,
        payload: crossSectionResponse,
      })
    ).toEqual(crossSectionLoadDataSuccessState);
  });
});
