import { mapReducer } from './reducer';
import { LatLng } from 'leaflet';
import {
  MapActionTypes,
  FIND_WELLS_SUCCESS,
  FIND_WELLS_START,
  FIND_WELLS_FAIL,
  ADD_POINT,
  CHANGE_POINT,
  DELETE_POINT,
  FINISH_DRAW_MODE,
  SET_USER_POSITION,
  SET_INITIAL_WELL,
  SET_MAP_ZOOM,
  SET_MAP_CENTER,
  MAKE_POINT_REAL,
  CLEAR_ALL_POINTS,
  TOGGLE_WELL_SELECTION,
  CLEAR_SEARCH_ERROR,
} from './types';
import {
  fetchWellsInPolygonResponse,
  mapInitialState,
  mapWithPointState,
  mapWithChangedPointState,
  mapWithUserPositionState,
  mapFindWellsStartState,
  mapFindWellsSuccessState,
  mapFindWellsFailState,
  mapEditingModeState,
  mapWithInitialWellState,
  mapWithCustomZoomState,
  mapWithCustomCenterState,
  mapWithSeveralPointsState,
  mapWithEditPointState,
  mapWithSelectedWelltate,
  mapErrorClosedtate,
} from 'test-data/map';

describe('Map reducer', () => {
  it('should return default state', () => {
    expect(mapReducer(undefined, {} as MapActionTypes)).toEqual(mapInitialState);
  });

  it('should handle SET_INITIAL_WELL', () => {
    expect(
      mapReducer(mapInitialState, {
        type: SET_INITIAL_WELL,
        payload: {
          facilityId: 'WellName1',
          location: new LatLng(1, 2),
          wellId: 'opendes:master-data--Well:1111',
        },
      })
    ).toEqual(mapWithInitialWellState);
  });

  it('should handle SET_USER_POSITION', () => {
    expect(
      mapReducer(mapInitialState, {
        type: SET_USER_POSITION,
        payload: new LatLng(1, 2),
      })
    ).toEqual(mapWithUserPositionState);
  });

  it('should handle SET_MAP_ZOOM', () => {
    expect(
      mapReducer(mapInitialState, {
        type: SET_MAP_ZOOM,
        payload: 3,
      })
    ).toEqual(mapWithCustomZoomState);
  });

  it('should handle SET_MAP_CENTER', () => {
    expect(
      mapReducer(mapInitialState, {
        type: SET_MAP_CENTER,
        payload: new LatLng(1, 2),
      })
    ).toEqual(mapWithCustomCenterState);
  });

  it('should handle FINISH_DRAW_MODE', () => {
    expect(
      mapReducer(mapInitialState, {
        type: FINISH_DRAW_MODE,
      })
    ).toEqual(mapEditingModeState);
  });

  it('should handle ADD_POINT', () => {
    expect(
      mapReducer(mapInitialState, {
        type: ADD_POINT,
        payload: new LatLng(1, 2),
      })
    ).toEqual(mapWithPointState);
  });

  it('should handle CHANGE_POINT', () => {
    expect(
      mapReducer(mapWithPointState, {
        type: CHANGE_POINT,
        payload: {
          id: 'p0',
          position: new LatLng(3, 4),
        },
      })
    ).toEqual(mapWithChangedPointState);
  });

  it('should handle DELETE_POINT', () => {
    expect(
      mapReducer(mapWithPointState, {
        type: DELETE_POINT,
        payload: 'p0',
      })
    ).toEqual(mapInitialState);
  });

  it('should handle MAKE_POINT_REAL', () => {
    expect(
      mapReducer(mapWithEditPointState, {
        type: MAKE_POINT_REAL,
        payload: 'p0',
      })
    ).toEqual(mapWithPointState);
  });

  it('should handle CLEAR_ALL_POINTS', () => {
    expect(
      mapReducer(mapWithSeveralPointsState, {
        type: CLEAR_ALL_POINTS,
      })
    ).toEqual(mapInitialState);
  });

  it('should handle TOGGLE_WELL_SELECTION', () => {
    expect(
      mapReducer(mapInitialState, {
        type: TOGGLE_WELL_SELECTION,
        payload: 'opendes:master-data--Well:1111',
      })
    ).toEqual(mapWithSelectedWelltate);

    expect(
      mapReducer(mapWithSelectedWelltate, {
        type: TOGGLE_WELL_SELECTION,
        payload: 'opendes:master-data--Well:1111',
      })
    ).toEqual(mapInitialState);
  });

  it('should handle FIND_WELLS_START', () => {
    expect(
      mapReducer(mapInitialState, {
        type: FIND_WELLS_START,
      })
    ).toEqual(mapFindWellsStartState);
  });

  it('should handle FIND_WELLS_SUCCESS', () => {
    expect(
      mapReducer(mapInitialState, {
        type: FIND_WELLS_SUCCESS,
        payload: fetchWellsInPolygonResponse,
      })
    ).toEqual(mapFindWellsSuccessState);
  });

  it('should handle FIND_WELLS_FAIL', () => {
    expect(
      mapReducer(mapInitialState, {
        type: FIND_WELLS_FAIL,
        payload: Error('Forbidden'),
      })
    ).toEqual(mapFindWellsFailState);
  });

  it('should handle CLEAR_SEARCH_ERROR', () => {
    expect(
      mapReducer(mapFindWellsFailState, {
        type: CLEAR_SEARCH_ERROR,
      })
    ).toEqual(mapErrorClosedtate);
  });
});
