import { MapState } from 'store/map';
import { LatLng } from 'leaflet';

export const mapInitialState: MapState = {
  currentUserPosition: undefined,
  mapCenter: undefined,
  mapZoom: 8,
  isDrawingMode: true,
  points: [],
  wells: [],
  selectedWellIds: [],
  isLoading: false,
  loadingError: undefined,
  initialWell: undefined,
};

export const mapWithInitialWellState: MapState = {
  ...mapInitialState,
  initialWell: {
    facilityId: 'WellName1',
    location: new LatLng(1, 2),
    wellId: 'opendes:master-data--Well:1111',
  },
  mapZoom: 15,
};

export const mapWithPointState: MapState = {
  ...mapInitialState,
  points: [
    {
      id: 'p0',
      position: new LatLng(1, 2),
      type: 'real',
    },
  ],
};

export const mapWithChangedPointState: MapState = {
  ...mapInitialState,
  points: [
    {
      id: 'p0',
      position: new LatLng(3, 4),
      type: 'real',
    },
  ],
};

export const mapWithSeveralPointsState: MapState = {
  ...mapInitialState,
  points: [
    {
      id: 'p0',
      position: new LatLng(1, 2),
      type: 'real',
    },
    {
      id: 'p1',
      position: new LatLng(3, 4),
      type: 'real',
    },
  ],
};

export const mapWithEditPointState: MapState = {
  ...mapInitialState,
  points: [
    {
      id: 'p0',
      position: new LatLng(1, 2),
      type: 'edit',
    },
  ],
};

export const mapEditingModeState: MapState = {
  ...mapInitialState,
  isDrawingMode: false,
};

export const mapWithUserPositionState: MapState = {
  ...mapInitialState,
  currentUserPosition: new LatLng(1, 2),
};

export const mapWithCustomZoomState: MapState = {
  ...mapInitialState,
  mapZoom: 3,
};

export const mapWithCustomCenterState: MapState = {
  ...mapInitialState,
  mapCenter: new LatLng(1, 2),
};

export const mapFindWellsStartState: MapState = {
  ...mapInitialState,
  isLoading: true,
};

export const mapFindWellsSuccessState: MapState = {
  ...mapInitialState,
  isLoading: false,
  wells: [
    {
      wellId: 'opendes:master-data--Well:1111',
      facilityId: 'WellName1',
      location: new LatLng(2, 1),
    },
    {
      wellId: 'opendes:master-data--Well:2222',
      facilityId: 'WellName2',
      location: new LatLng(4, 3),
    },
    {
      wellId: 'opendes:master-data--Well:3333',
      facilityId: 'WellName3',
      location: new LatLng(6, 5),
    },
  ],
};

export const mapFindWellsFailState: MapState = {
  ...mapInitialState,
  isLoading: false,
  loadingError: Error('Forbidden'),
};

export const mapWithSelectedWelltate: MapState = {
  ...mapInitialState,
  selectedWellIds: ['opendes:master-data--Well:1111'],
};

export const mapErrorClosedtate: MapState = {
  ...mapFindWellsFailState,
  loadingError: undefined,
};
