import { WellSearchState, WellSearchResponse } from 'store/well-search';
import { GeoJSON } from 'leaflet';

export const wellSearchInitialState: WellSearchState = {
  searchName: 'BIR',
  areWellsSearching: false,
  areWellsSearched: false,
  foundWells: [],
  searchError: undefined,
};

export const wellSearchWellsFindStartState: WellSearchState = {
  ...wellSearchInitialState,
  areWellsSearching: true,
};

export const wellSearchWellsFindSuccessState: WellSearchState = {
  ...wellSearchWellsFindStartState,
  areWellsSearching: false,
  areWellsSearched: true,
  foundWells: [
    {
      facilityId: 'WellName1',
      wellId: 'opendes:master-data--Well:1111',
      location: GeoJSON.coordsToLatLng([11, 12]),
      wellbores: [],
      areWellboresLoaded: false,
      areWellboresLoading: false,
    },
    {
      facilityId: 'WellName2',
      wellId: 'opendes:master-data--Well:2222',
      location: GeoJSON.coordsToLatLng([21, 22]),
      wellbores: [],
      areWellboresLoaded: false,
      areWellboresLoading: false,
    },
  ],
};

export const wellSearchWellsFindFailState: WellSearchState = {
  ...wellSearchWellsFindStartState,
  areWellsSearching: false,
  areWellsSearched: true,
  searchError: Error('Forbidden'),
};

export const wellSearchWellboresFindStartState: WellSearchState = {
  ...wellSearchWellsFindSuccessState,
  foundWells: wellSearchWellsFindSuccessState.foundWells.map(
    (w, i): WellSearchResponse =>
      i === 0
        ? {
          ...w,
          areWellboresLoading: true,
        }
        : w
  ),
};

export const wellSearchWellboresFindSuccessState: WellSearchState = {
  ...wellSearchWellboresFindStartState,
  foundWells: wellSearchWellboresFindStartState.foundWells.map(
    (w, i): WellSearchResponse =>
      i === 0
        ? {
          ...w,
          areWellboresLoading: false,
          areWellboresLoaded: true,
          wellbores: [
            {
              wellboreId: 'opendes:master-data--Wellbore:1111',
              wellboreName: 'WellboreName1',
            },
            {
              wellboreId: 'opendes:master-data--Wellbore:2222',
              wellboreName: 'WellboreName2',
            },
          ],
        }
        : w
  ),
};

export const wellSearchWellboresFindFailState: WellSearchState = {
  ...wellSearchWellboresFindStartState,
  foundWells: wellSearchWellboresFindStartState.foundWells.map(
    (w, i): WellSearchResponse =>
      i === 0
        ? {
          ...w,
          areWellboresLoading: false,
          areWellboresLoaded: true,
          wellboresError: Error('Forbidden'),
        }
        : w
  ),
};
